local _, L = ...
local mediaFolder = "Interface\\AddOns\\".._.."\\Media\\"

--local LCG = LibStub('LibCustomGlow-1.0')
--local RCH = LibStub("LibRangeCheck-2.0")
local LSM = LibStub('LibSharedMedia-3.0')

local select = select
local unpack = unpack
local pairs = pairs
local print = print
local table_insert = table.insert
local table_sort = table.sort
local table_remove = table.remove
local table_concat = table.concat
local string_char = string.char
local string_byte = string.byte
local string_len = string.len
local string_gsub = string.gsub
local string_match = string.match
local string_format = string.format
local string_find = string.find
local math_fmod = math.fmod
local math_floor = math.floor
local math_ceil = math.ceil
local Lerp = Lerp

local CreateFrame = CreateFrame
local SetFrameLevel = SetFrameLevel
local ClearAllPoints = ClearAllPoints
local CreateTexture = CreateTexture
local SetVertexColor = SetVertexColor
local SetStatusBarColor = SetStatusBarColor
local SetTexture = SetTexture
local C_NamePlate_GetNamePlateForUnit = C_NamePlate.GetNamePlateForUnit
local C_NamePlate_GetNamePlates = C_NamePlate.GetNamePlates
local UnitExists = UnitExists
local UnitHealth = UnitHealth
local UnitHealthMax = UnitHealthMax
local UnitIsUnit = UnitIsUnit
local UnitName = UnitName
local UnitPowerType = UnitPowerType
local RAID_CLASS_COLORS = RAID_CLASS_COLORS
local GetRuneCooldown = GetRuneCooldown
local SetMinMaxValues = SetMinMaxValues


classBarMixin = {}

function classBarMixin:ClassBarUpdateRune()
	for runeIndex = 1, 6 do
		local start, duration, runeReady = GetRuneCooldown(runeIndex)
		if not runeReady then
			myClassBar[runeIndex]:SetStatusBarColor(unpack(L.config.player_resource_color_empty))
			if start then
				myClassBar[runeIndex].class_points_max = duration
				myClassBar[runeIndex].duration = GetTime() - start
				myClassBar[runeIndex]:SetScript("OnUpdate", 
					function(self, elapsed)
						self.duration = self.duration + elapsed
						if self.duration >= self.class_points_max or self.duration <= 0 then
							self.value:SetText(nil)
						else
							self.value:SetText(namePlateMixin:FormatTime(self.class_points_max - self.duration))
						end
					end
				)
				myClassBar[runeIndex].value:Show()
			end
		else
			myClassBar[runeIndex]:SetStatusBarColor(unpack(L.config.player_resource_color_full))
			myClassBar[runeIndex]:SetScript("OnUpdate", nil)
			myClassBar[runeIndex].value:SetText(nil)
		end
		myClassBar[runeIndex]:Show()
	end
end

function classBarMixin:ClassBarUpdateKick(kicker)
	if not kicker then return end
	local i = 0
	if kicker == UnitName("player") then 
		i = 5
	else
		i = namePlateMixin:IsPartyName(kicker)
	end

	
	if i == 0 then 
		if namePlateMixin.KICKERS_TABLE[kicker] then
			namePlateMixin.KICKERS_TABLE[kicker] = nil
		end
	else
		namePlateMixin.KICKERS_TABLE[kicker].index = i
		myClassBar[i].border.bg:SetVertexColor(namePlateMixin.KICKERS_TABLE[kicker].classColor.r, namePlateMixin.KICKERS_TABLE[kicker].classColor.g, namePlateMixin.KICKERS_TABLE[kicker].classColor.b, namePlateMixin.KICKERS_TABLE[kicker].classColor.a)
		myClassBar[i]:SetStatusBarColor(namePlateMixin.KICKERS_TABLE[kicker].classColor.r / 3, namePlateMixin.KICKERS_TABLE[kicker].classColor.g / 3, namePlateMixin.KICKERS_TABLE[kicker].classColor.b / 3, namePlateMixin.KICKERS_TABLE[kicker].classColor.a)
		myClassBar[i]:SetMinMaxValues(0, L.inperruptSpellTable[namePlateMixin.KICKERS_TABLE[kicker].kickSpell].cd)
		myClassBar[i].border.shadow:SetBackdropBorderColor(namePlateMixin.KICKERS_TABLE[kicker].classColor.r, namePlateMixin.KICKERS_TABLE[kicker].classColor.g, namePlateMixin.KICKERS_TABLE[kicker].classColor.b, 1)
		myClassBar[i]:SetReverseFill(true)
		myClassBar[i]:Show()
					
		if  namePlateMixin.KICKERS_TABLE[kicker].expirationTime > GetTime() then
			myClassBar[i].border.shadow:Hide()
			myClassBar[i].expirationTime = namePlateMixin.KICKERS_TABLE[kicker].expirationTime
			myClassBar[i]:SetScript("OnUpdate",
				function(self, elapsed)
					local timeLeft = self.expirationTime - GetTime()
					if timeLeft > 0 then
						PixelUtil.SetStatusBarValue(self, timeLeft)
					else
						if L.config.party_kick_bars_shadow then 
							self.border.shadow:Show()
						end
						self:SetScript("OnUpdate", nil)
						PixelUtil.SetStatusBarValue(self, 0)
					end
				end
			)
		else
			PixelUtil.SetStatusBarValue(myClassBar[i], 0)
			if L.config.party_kick_bars_shadow then
				myClassBar[i].border.shadow:Show()
			else
				myClassBar[i].border.shadow:Hide()
			end
		end
	end
end

function classBarMixin:ClassBarUpdateStagger()
	local currstagger = UnitStagger("player")
	if currstagger then 
		local maxhp = UnitHealthMax("player")
		local percent = currstagger/maxhp
		local color = PowerBarColor[BREWMASTER_POWER_BAR_NAME]

		if (percent > STAGGER_YELLOW_TRANSITION and percent < STAGGER_RED_TRANSITION) then
			color = color[STAGGER_YELLOW_INDEX]
		elseif (percent > STAGGER_RED_TRANSITION) then
			color = color[STAGGER_RED_INDEX]
		else
			color = color[STAGGER_GREEN_INDEX]
		end
	
		myClassBar[1].value:SetText(GetSpellCharges(119582))
		myClassBar[1].value:Show()
		myClassBar[1]:SetStatusBarColor(color.r, color.g, color.b)
		myClassBar[1].border.bg:SetVertexColor(color.r / 3, color.g / 3, color.b / 3)
		myClassBar[1]:SetMinMaxValues(0, maxhp)
		myClassBar[1]:Show()
		
		PixelUtil.SetStatusBarValue(myClassBar[1], currstagger)
	end
end

function classBarMixin:ClassBarUpdateCP()
	local class_points_current, class_points_max = UnitPower('player', L.config.selfPlayerInfo[L.config.selfPlayerInfo.myClass][L.config.selfPlayerInfo.mySpec].enumPowerType), UnitPowerMax('player', L.config.selfPlayerInfo[L.config.selfPlayerInfo.myClass][L.config.selfPlayerInfo.mySpec].enumPowerType)
	local chargedPowerPoints = GetUnitChargedPowerPoints("player")
	local chargedPowerPointIndex = chargedPowerPoints and chargedPowerPoints[1] or 0
	for i = 1, class_points_max do
		if (i <= class_points_current) then
			if class_points_current == class_points_max then
				myClassBar[i]:SetStatusBarColor(unpack(L.config.player_resource_color[6]))
			else
				myClassBar[i]:SetStatusBarColor(unpack(L.config.player_resource_color[i]))
			end
			if chargedPowerPointIndex == i then
				myClassBar[i]:SetStatusBarColor( 1, .5, 0, 1)
			end
			myClassBar[i]:Show()
		else
			myClassBar[i]:Hide()
		end
	end

	if L.config.player_resource_sound_enable then
		if (class_points_current >= class_points_max) and not myClassBar.sound_played then
			myClassBar.sound_played = true
			PlaySoundFile(LSM:Fetch(LSM.MediaType.SOUND, L.config.player_resource_sound), L.config.sound_channel)
		elseif (class_points_current < class_points_max) then
			myClassBar.sound_played = false
		end
	end
end

function classBarMixin:ClassBarUpdateMaelstorm()
	local maelstorm_count = select(3, GetPlayerAuraBySpellID(344179)) or 0
	local hailstorm_count = select(3, GetPlayerAuraBySpellID(334196)) or 0
	local class_points_max = 10

	if maelstorm_count then
		for i = 1, class_points_max do
			if (i <= maelstorm_count) then
				if hailstorm_count == 0 and maelstorm_count > 4 then 
					myClassBar[i]:SetStatusBarColor(unpack(L.config.player_resource_color[6]))
				else
					myClassBar[i]:SetStatusBarColor(unpack(L.config.player_resource_color[1]))
				end
				myClassBar[i]:Show()
			else
				myClassBar[i]:Hide()
			end
		end
	end
	
	if L.config.player_resource_sound_enable then
		if maelstorm_count >= 5 and hailstorm_count == 0 and not myClassBar.sound_played then
			myClassBar.sound_played = true
			PlaySoundFile(LSM:Fetch(LSM.MediaType.SOUND, L.config.player_resource_sound), L.config.sound_channel)
		elseif maelstorm_count < 5 or hailstorm_count > 0 then
			myClassBar.sound_played = false
		end
	end
end

function classBarMixin:ClassBarUpdateHB(event, unit)
	if (event == "PLAYER_ENTERING_WORLD" or event == "GROUP_ROSTER_UPDATE") then
		if not unit then unit = "player" end
		for i = 1, MAX_PARTY_MEMBERS + 1, 1 do
			local partyUnit = (i == 5) and "player" or "party"..i
			
			if ( UnitExists(partyUnit) ) then
				local _, englishClass = UnitClass(partyUnit)
				local classColor = RAID_CLASS_COLORS[englishClass]
				if classColor then
					myClassBar[i]:SetStatusBarColor(classColor.r, classColor.g, classColor.b)
					myClassBar[i].border.bg:SetVertexColor(classColor.r / 3, classColor.g / 3, classColor.b / 3)
				end
				myClassBar[i]:SetMinMaxValues(0, 1)
				myClassBar[i].unit = partyUnit
				myClassBar[i]:Show()
			else
				myClassBar[i].unit = nil
				myClassBar[i]:Hide()
			end
		end
	
	elseif (event == "UNIT_AURA" and L.config.selfPlayerInfo[L.config.selfPlayerInfo.myClass][L.config.selfPlayerInfo.mySpec].dispelableDebuffTable.classHasDispell) then
		local showBorderShadow = false
		for index = 1, BUFF_MAX_DISPLAY do
			local name, _, _, debuffType = UnitAura(unit, index, 'HARMFUL')
			if L.config.selfPlayerInfo[L.config.selfPlayerInfo.myClass][L.config.selfPlayerInfo.mySpec].dispelableDebuffTable[debuffType] then
				showBorderShadow = true
				break
			end
		end
		
		for i = 1, MAX_PARTY_MEMBERS + 1, 1 do
			if myClassBar[i].unit == unit then
				if showBorderShadow then
					namePlateMixin:SetMyBorderColor(myClassBar[i].border, 0.2, 0.8, 0.2, 1)
					myClassBar[i].border.shadow:Show()
				else
					namePlateMixin:SetMyBorderColor(myClassBar[i].border, 0, 0, 0, 1)
					myClassBar[i].border.shadow:Hide()
				end
			end
		end
	
	elseif (event == "UNIT_HEALTH") then
		for i = 1, MAX_PARTY_MEMBERS + 1, 1 do
			if myClassBar[i].unit == unit then
				local perc = UnitHealth(unit) / UnitHealthMax(unit)
				if L.config.party_health_bars_dynamic_size then
					myClassBar[i]:SetSize(myClassBar.tmpSize, L.config.player_resource_position_height[L.config.player_resource_pine] * (2 - perc))
				else
					myClassBar[i]:SetSize(myClassBar.tmpSize, L.config.player_resource_position_height[L.config.player_resource_pine])
				end
				PixelUtil.SetStatusBarValue(myClassBar[i], perc)
			end
		end
	end
end

function classBarMixin:ClassBarUpdatePosition()
	if L.config.player_resource_pine == "screen" then
		myClassBar:ClearAllPoints()
		myClassBar:SetPoint("CENTER", UIParent, "CENTER", 0, L.config.player_resource_position_y[L.config.player_resource_pine])
		if myClassBar.show then
			myClassBar:Show()
		end
	else
		local myClassBarPlate = C_NamePlate_GetNamePlateForUnit(L.config.player_resource_pine, issecure())
		if myClassBarPlate and not (myClassBarPlate.UnitFrame.isSelfPlayer and L.config.player_resource_pine == "target") then
			myClassBar:ClearAllPoints()
			myClassBar:SetPoint("BOTTOM", myClassBarPlate.UnitFrame.healthBar, "TOP", 0, L.config.player_resource_position_y[L.config.player_resource_pine]) -- + (myClassBarPlate.UnitFrame.powerBar:IsShown() and L.config.powerbar_height or 0))
			myClassBar:SetFrameLevel(myClassBarPlate:GetFrameLevel())
			if myClassBar.show then
				myClassBar:Show()
			end
		else
			myClassBar:Hide()
		end
	end
end

function classBarMixin:ClassBarUpdateEvents(who)
	myClassBar.type = L.config.player_resource_type
	--print(who)
	
	for _, event in pairs({
		"PLAYER_ENTERING_WORLD",
		"NAME_PLATE_UNIT_ADDED",
		"NAME_PLATE_UNIT_REMOVED",
		"PLAYER_TARGET_CHANGED",
		"RUNE_POWER_UPDATE",
		"UNIT_HEALTH",
		"UNIT_AURA",
		"UNIT_POWER_UPDATE",
		"UNIT_DISPLAYPOWER",
		"GROUP_ROSTER_UPDATE",
	}) do myClassBar:UnregisterEvent(event) end
	myClassBar:SetScript("OnUpdate", nil)
	
	if L.config.player_resource_type == 0 then
		myClassBar:Hide()
		myClassBar.show = false
		
	elseif L.config.selfPlayerInfo.myClass == "DEATHKNIGHT" and L.config.player_resource_type == 1 then
		myClassBar:RegisterEvent("RUNE_POWER_UPDATE")
		myClassBar.show = true
					
	elseif L.config.selfPlayerInfo.myClass == "MONK" and L.config.selfPlayerInfo.mySpec == SPEC_MONK_BREWMASTER and L.config.player_resource_type == 1 then
		myClassBar:RegisterEvent("UNIT_HEALTH")
		myClassBar.show = true

	elseif L.config.selfPlayerInfo.myClass == "SHAMAN" and L.config.selfPlayerInfo.mySpec == 2 and L.config.player_resource_type == 1 then
		myClassBar:RegisterEvent("UNIT_AURA")
		myClassBar.show = true
		
	elseif namePlateMixin:MultiCheck(L.config.selfPlayerInfo.myClass, "WARLOCK", "PALADIN", "MONK", "MAGE", "ROGUE", "DRUID") 
		and L.config.selfPlayerInfo[L.config.selfPlayerInfo.myClass][L.config.selfPlayerInfo.mySpec].powerToken 
		and L.config.player_resource_type == 1 then
		
		if L.config.selfPlayerInfo.myClass == "DRUID" then
			myClassBar:RegisterUnitEvent("UNIT_DISPLAYPOWER", "player")
		end
		myClassBar:RegisterUnitEvent("UNIT_POWER_UPDATE", "player")
		myClassBar.show = true
			
	elseif L.config.player_resource_type == 2 then
		myClassBar:RegisterEvent("GROUP_ROSTER_UPDATE")
		myClassBar:RegisterEvent("UNIT_HEALTH")
		if L.config.selfPlayerInfo[L.config.selfPlayerInfo.myClass][L.config.selfPlayerInfo.mySpec].dispelableDebuffTable.classHasDispell then
			myClassBar:RegisterEvent("UNIT_AURA")
		end
		myClassBar.show = true
		
	elseif L.config.player_resource_type == 3 then
		myClassBar:RegisterEvent("GROUP_ROSTER_UPDATE")
		myClassBar.show = true
	
	else
		myClassBar:SetScript("OnUpdate", nil)
		myClassBar:Hide()
		myClassBar.show = false
	end

	if myClassBar.show then
		for _, event in pairs({
			"PLAYER_ENTERING_WORLD",
			"NAME_PLATE_UNIT_ADDED",
			"NAME_PLATE_UNIT_REMOVED",
			"PLAYER_TARGET_CHANGED",
		}) do myClassBar:RegisterEvent(event) end
	end
end

function classBarMixin:UpdateStatusBars(val)
	myClassBar:SetFrameLevel(1)
	myClassBar.maxBars = val
	myClassBar.sound_played = true
	myClassBar:SetSize( L.config.player_resource_position_width[L.config.player_resource_pine], L.config.player_resource_position_height[L.config.player_resource_pine])
	myClassBar.tmpSize = math_floor((L.config.player_resource_position_width[L.config.player_resource_pine]-((myClassBar.maxBars - 1)* L.config.player_resource_position_space[L.config.player_resource_pine])) / myClassBar.maxBars)
	for i = 1, 10 do
		myClassBar[i] = myClassBar[i] or CreateFrame("StatusBar", "myClassBar"..i, myClassBar)
		myClassBar[i]:SetScript("OnUpdate", nil)
		if i <= myClassBar.maxBars then
			myClassBar[i].border = myClassBar[i].border or namePlateMixin:CreateMyBackdrop(myClassBar[i], 1, 0, 0, 0, 1, LSM:Fetch(LSM.MediaType.STATUSBAR, L.config.player_resource_texture), 0, 0, 0, 1, 6, 0, 1, 0, 0.8)
			myClassBar[i].border.shadow:Hide()
			myClassBar[i]:SetMinMaxValues(0, 1)
			PixelUtil.SetStatusBarValue(myClassBar[i], 1)
			myClassBar[i].value = myClassBar[i].value or namePlateMixin:CreateMyText(myClassBar[i], L.config.name_font_npc, L.config.player_resource_position_height[L.config.player_resource_pine] + 1, "OUTLINE", "OVERLAY", "CENTER", "CENTER", false)
			myClassBar[i].value:SetFont(LSM:Fetch(LSM.MediaType.FONT, L.config.name_font_npc), L.config.player_resource_position_height[L.config.player_resource_pine] + 1 , L.config.name_font_flag_npc)
			myClassBar[i].value:Hide()
		
			myClassBar[i]:SetStatusBarTexture(LSM:Fetch(LSM.MediaType.STATUSBAR, L.config.player_resource_texture))
			myClassBar[i].border.bg:SetTexture(LSM:Fetch(LSM.MediaType.STATUSBAR, L.config.player_resource_texture))
			PixelUtil.SetSize(myClassBar[i], myClassBar.tmpSize, L.config.player_resource_position_height[L.config.player_resource_pine])
				
			if i == 1 then
				PixelUtil.SetPoint(myClassBar[i], "BOTTOMLEFT", myClassBar, "BOTTOMLEFT", 0, 0)
			else
				PixelUtil.SetPoint(myClassBar[i], "LEFT", myClassBar[i-1], "RIGHT", L.config.player_resource_position_space[L.config.player_resource_pine], 0)
			end
		end
		myClassBar[i]:Hide()
	end
end

local function OnClassBarUpdate(myClassBar, event, unit, powerType, refresh)
	if myClassBar.type ~= L.config.player_resource_type or refresh then
		classBarMixin:ClassBarUpdateEvents("OnClassBarUpdate type ~= player_resource_type")
	end
	
	if refresh then
		classBarMixin:ClassBarUpdatePosition()
	end
	
	if L.config.player_resource_type and L.config.player_resource_type > 0 then
	
		if (event == "NAME_PLATE_UNIT_ADDED" or event == "PLAYER_TARGET_CHANGED") then
			if (event == "NAME_PLATE_UNIT_ADDED" and L.config.player_resource_pine == "player" and UnitIsUnit(unit, "player"))
			or (event == "NAME_PLATE_UNIT_ADDED" and L.config.player_resource_pine == "target" and UnitIsUnit(unit, "target"))
			or (event == "PLAYER_TARGET_CHANGED" and L.config.player_resource_pine == "target")
			or L.config.player_resource_pine == "screen" then
				classBarMixin:ClassBarUpdatePosition()
			end
		
		elseif ((event == "NAME_PLATE_UNIT_REMOVED" and L.config.player_resource_pine == "player" and UnitIsUnit(unit, "player"))
			or (event == "NAME_PLATE_UNIT_REMOVED" and L.config.player_resource_pine == "target" and UnitIsUnit(unit, "target"))) then
			myClassBar:Hide()
		
		elseif event == "PLAYER_TALENT_UPDATE" then
			myClassBar.show = false
			myClassBar:Hide()
			classBarMixin:ClassBarUpdateEvents("OnClassBarUpdate PLAYER_TALENT_UPDATE")
			
		elseif L.config.player_resource_type == 1 and L.config.selfPlayerInfo.myClass == "DEATHKNIGHT" then
			if  (event == "PLAYER_ENTERING_WORLD" or event == "RUNE_POWER_UPDATE") then
				classBarMixin:ClassBarUpdateRune()
				myClassBar.show = true
			elseif refresh then
				classBarMixin:UpdateStatusBars(6)
				classBarMixin:ClassBarUpdateRune()
			end
	
		elseif L.config.player_resource_type == 1 and L.config.selfPlayerInfo.myClass == "MONK" and L.config.selfPlayerInfo.mySpec == SPEC_MONK_BREWMASTER then
			if (event == "UNIT_HEALTH" and unit == "player") then
				classBarMixin:ClassBarUpdateStagger()
				myClassBar.show = true
			elseif refresh then
				classBarMixin:UpdateStatusBars(1)
				classBarMixin:ClassBarUpdateStagger()
			end
			
		elseif L.config.player_resource_type == 1 and L.config.selfPlayerInfo.myClass == "SHAMAN" and L.config.selfPlayerInfo.mySpec == 2 then
			if (event == "UNIT_AURA" and unit == "player") then
				classBarMixin:ClassBarUpdateMaelstorm()
				myClassBar.show = true
			elseif refresh then
				classBarMixin:UpdateStatusBars(10)
				classBarMixin:ClassBarUpdateMaelstorm()
			end
			
		elseif L.config.player_resource_type == 1 and L.config.selfPlayerInfo[L.config.selfPlayerInfo.myClass][L.config.selfPlayerInfo.mySpec].powerToken and (namePlateMixin:MultiCheck(L.config.selfPlayerInfo.myClass, "WARLOCK", "PALADIN", "MONK", "MAGE", "ROGUE", "DRUID")) then
			if (event == "PLAYER_ENTERING_WORLD" or (event == "UNIT_POWER_UPDATE" and unit == "player" and powerType == L.config.selfPlayerInfo[L.config.selfPlayerInfo.myClass][L.config.selfPlayerInfo.mySpec].powerToken)) then
				classBarMixin:ClassBarUpdateCP()
				myClassBar.show = true
			elseif refresh then
				classBarMixin:UpdateStatusBars(UnitPowerMax('player', L.config.selfPlayerInfo[L.config.selfPlayerInfo.myClass][L.config.selfPlayerInfo.mySpec].enumPowerType))
				classBarMixin:ClassBarUpdateCP()
			end
	
		elseif L.config.player_resource_type == 2 then
			if (event == "PLAYER_ENTERING_WORLD" or event == "GROUP_ROSTER_UPDATE") or ((event == "UNIT_HEALTH" or event == "UNIT_AURA") and (UnitInParty(unit) or unit == "player")) then
				classBarMixin:ClassBarUpdateHB(event, unit)
				myClassBar.show = true
			elseif refresh then
				classBarMixin:UpdateStatusBars(MAX_PARTY_MEMBERS + 1)
				classBarMixin:ClassBarUpdateHB("GROUP_ROSTER_UPDATE", nil)
			end
			
		elseif L.config.player_resource_type == 3 then
			if (event == "PLAYER_ENTERING_WORLD" or event == "GROUP_ROSTER_UPDATE") then
				namePlateMixin:RefreshKickerTable()
				myClassBar.show = true
				
			elseif refresh then
				classBarMixin:UpdateStatusBars(MAX_PARTY_MEMBERS + 1)
				namePlateMixin:RefreshKickerTable()
			end
			
		elseif L.config.player_resource_type == 1 and event == "UNIT_DISPLAYPOWER" then
			if L.config.selfPlayerInfo.myClass == "DRUID" then
				local powerType, powerToken =  UnitPowerType("player")
				if (powerType == Enum.PowerType.Energy) then
					myClassBar:Show()
				else
					myClassBar:Hide()
				end
			else
				myClassBar:Show()
			end
		end
	else		
		myClassBar:Hide()
	end
end
			

function classBarMixin:UpdateClassBar()
	OnClassBarUpdate(myClassBar, nil, nil, nil, true)
end

function classBarMixin:OnEvent(event, ...)
	if ( event == "ADDON_LOADED" ) then
		local name = ...
		if name == _ then
			classBarMixin:UpdateStatusBars(10)
		
			myClassBar:SetScript("OnEvent", OnClassBarUpdate)
			myClassBar:RegisterEvent("PLAYER_TALENT_UPDATE")
			
			if IsAddOnLoaded(_) then
				self:UnregisterEvent('ADDON_LOADED')
				self.ADDON_LOADED = nil
			end
		end
	end
end

function classBarMixin:OnLoad()
	for _, event in pairs({
		"ADDON_LOADED",
	}) do self:RegisterEvent(event) end
end
